# Awesome Calculator

A colorful command-line calculator built in Python. It supports operations like:

- Addition
- Subtraction
- Multiplication
- Division
- Percentage
- Square root
- Power

Includes colored CLI using `colorama` for enhanced UX.

## Usage

Install it:

```bash
pip install awesome-calculator
```

Run it:
```bash
awesome-calculator
```